==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/metainfo.cpp <==
#include <QtJambi/MetaInfo>


void initialize_meta_info_registerParserStatusCaster();
void initialize_meta_info_QQuickAsyncImageProvider();
void initialize_meta_info_QQuickCloseEvent();
void initialize_meta_info_QQuickFramebufferObject();
void initialize_meta_info_QQuickFramebufferObject_Renderer();
void initialize_meta_info_QQuickImageProvider();
void initialize_meta_info_QQuickImageResponse();
void initialize_meta_info_QQuickItem();
void initialize_meta_info_QQuickItem_UpdatePaintNodeData();
void initialize_meta_info_QQuickItemGrabResult();
void initialize_meta_info_QQuickPaintedItem();
void initialize_meta_info_QQuickRenderControl();
void initialize_meta_info_QQuickTextDocument();
void initialize_meta_info_QQuickTextureFactory();
void initialize_meta_info_QQuickTransform();
void initialize_meta_info_QQuickView();
void initialize_meta_info_QQuickWindow();
void initialize_meta_info_QQuickWindow_GraphicsStateInfo();
void initialize_meta_info_QSGAbstractRenderer();
void initialize_meta_info_QSGBasicGeometryNode();
void initialize_meta_info_QSGClipNode();
void initialize_meta_info_QSGDynamicTexture();
void initialize_meta_info_QSGEngine();
void initialize_meta_info_QSGFlatColorMaterial();
void initialize_meta_info_QSGGeometry();
void initialize_meta_info_QSGGeometry_Attribute();
void initialize_meta_info_QSGGeometry_AttributeSet();
void initialize_meta_info_QSGGeometry_ColoredPoint2D();
void initialize_meta_info_QSGGeometry_Point2D();
void initialize_meta_info_QSGGeometry_TexturedPoint2D();
void initialize_meta_info_QSGGeometryNode();
void initialize_meta_info_QSGImageNode();
void initialize_meta_info_QSGMaterial();
void initialize_meta_info_QSGMaterialRhiShader();
void initialize_meta_info_QSGMaterialRhiShader_GraphicsPipelineState();
void initialize_meta_info_QSGMaterialRhiShader_RenderState();
void initialize_meta_info_QSGMaterialShader();
void initialize_meta_info_QSGMaterialShader_RenderState();
void initialize_meta_info_QSGMaterialType();
void initialize_meta_info_QSGNinePatchNode();
void initialize_meta_info_QSGNode();
void initialize_meta_info_QSGNodeVisitor();
void initialize_meta_info_QSGOpacityNode();
void initialize_meta_info_QSGOpaqueTextureMaterial();
void initialize_meta_info_QSGRectangleNode();
void initialize_meta_info_QSGRenderNode();
void initialize_meta_info_QSGRenderNode_RenderState();
void initialize_meta_info_QSGRendererInterface();
void initialize_meta_info_QSGRootNode();
void initialize_meta_info_QSGSimpleRectNode();
void initialize_meta_info_QSGSimpleTextureNode();
void initialize_meta_info_QSGTexture();
void initialize_meta_info_QSGTextureMaterial();
void initialize_meta_info_QSGTextureProvider();
void initialize_meta_info_QSGTransformNode();
void initialize_meta_info_QSGVertexColorMaterial();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.quick")

    initialize_meta_info_registerParserStatusCaster();
    initialize_meta_info_QQuickAsyncImageProvider();
    initialize_meta_info_QQuickCloseEvent();
    initialize_meta_info_QQuickFramebufferObject();
    initialize_meta_info_QQuickFramebufferObject_Renderer();
    initialize_meta_info_QQuickImageProvider();
    initialize_meta_info_QQuickImageResponse();
    initialize_meta_info_QQuickItem();
    initialize_meta_info_QQuickItem_UpdatePaintNodeData();
    initialize_meta_info_QQuickItemGrabResult();
    initialize_meta_info_QQuickPaintedItem();
    initialize_meta_info_QQuickRenderControl();
    initialize_meta_info_QQuickTextDocument();
    initialize_meta_info_QQuickTextureFactory();
    initialize_meta_info_QQuickTransform();
    initialize_meta_info_QQuickView();
    initialize_meta_info_QQuickWindow();
    initialize_meta_info_QQuickWindow_GraphicsStateInfo();
    initialize_meta_info_QSGAbstractRenderer();
    initialize_meta_info_QSGBasicGeometryNode();
    initialize_meta_info_QSGClipNode();
    initialize_meta_info_QSGDynamicTexture();
    initialize_meta_info_QSGEngine();
    initialize_meta_info_QSGFlatColorMaterial();
    initialize_meta_info_QSGGeometry();
    initialize_meta_info_QSGGeometry_Attribute();
    initialize_meta_info_QSGGeometry_AttributeSet();
    initialize_meta_info_QSGGeometry_ColoredPoint2D();
    initialize_meta_info_QSGGeometry_Point2D();
    initialize_meta_info_QSGGeometry_TexturedPoint2D();
    initialize_meta_info_QSGGeometryNode();
    initialize_meta_info_QSGImageNode();
    initialize_meta_info_QSGMaterial();
    initialize_meta_info_QSGMaterialRhiShader();
    initialize_meta_info_QSGMaterialRhiShader_GraphicsPipelineState();
    initialize_meta_info_QSGMaterialRhiShader_RenderState();
    initialize_meta_info_QSGMaterialShader();
    initialize_meta_info_QSGMaterialShader_RenderState();
    initialize_meta_info_QSGMaterialType();
    initialize_meta_info_QSGNinePatchNode();
    initialize_meta_info_QSGNode();
    initialize_meta_info_QSGNodeVisitor();
    initialize_meta_info_QSGOpacityNode();
    initialize_meta_info_QSGOpaqueTextureMaterial();
    initialize_meta_info_QSGRectangleNode();
    initialize_meta_info_QSGRenderNode();
    initialize_meta_info_QSGRenderNode_RenderState();
    initialize_meta_info_QSGRendererInterface();
    initialize_meta_info_QSGRootNode();
    initialize_meta_info_QSGSimpleRectNode();
    initialize_meta_info_QSGSimpleTextureNode();
    initialize_meta_info_QSGTexture();
    initialize_meta_info_QSGTextureMaterial();
    initialize_meta_info_QSGTextureProvider();
    initialize_meta_info_QSGTransformNode();
    initialize_meta_info_QSGVertexColorMaterial();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_internal_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

==> qtjambi-quick-debuginfo-macos-6.6.0.jar: sources/QtJambiQuick/metainfo.cpp <==
#include <QtJambi/MetaInfo>


void initialize_meta_info_registerParserStatusCaster();
void initialize_meta_info_QNativeInterface_QSGD3D11Texture();
void initialize_meta_info_QNativeInterface_QSGD3D12Texture();
void initialize_meta_info_QNativeInterface_QSGMetalTexture();
void initialize_meta_info_QNativeInterface_QSGOpenGLTexture();
void initialize_meta_info_QNativeInterface_QSGVulkanTexture();
void initialize_meta_info_QQuickAsyncImageProvider();
void initialize_meta_info_QQuickCloseEvent();
void initialize_meta_info_QQuickFramebufferObject();
void initialize_meta_info_QQuickFramebufferObject_Renderer();
void initialize_meta_info_QQuickGraphicsConfiguration();
void initialize_meta_info_QQuickGraphicsDevice();
void initialize_meta_info_QQuickImageProvider();
void initialize_meta_info_QQuickImageResponse();
void initialize_meta_info_QQuickItem();
void initialize_meta_info_QQuickItem_UpdatePaintNodeData();
void initialize_meta_info_QQuickItemGrabResult();
void initialize_meta_info_QQuickOpenGLUtils();
void initialize_meta_info_QQuickPaintedItem();
void initialize_meta_info_QQuickRenderControl();
void initialize_meta_info_QQuickRenderTarget();
void initialize_meta_info_QQuickTextDocument();
void initialize_meta_info_QQuickTextureFactory();
void initialize_meta_info_QQuickTransform();
void initialize_meta_info_QQuickView();
void initialize_meta_info_QQuickWindow();
void initialize_meta_info_QQuickWindow_GraphicsStateInfo();
void initialize_meta_info_QSGBasicGeometryNode();
void initialize_meta_info_QSGClipNode();
void initialize_meta_info_QSGDynamicTexture();
void initialize_meta_info_QSGFlatColorMaterial();
void initialize_meta_info_QSGGeometry();
void initialize_meta_info_QSGGeometry_Attribute();
void initialize_meta_info_QSGGeometry_AttributeSet();
void initialize_meta_info_QSGGeometry_ColoredPoint2D();
void initialize_meta_info_QSGGeometry_Point2D();
void initialize_meta_info_QSGGeometry_TexturedPoint2D();
void initialize_meta_info_QSGGeometryNode();
void initialize_meta_info_QSGImageNode();
void initialize_meta_info_QSGMaterial();
void initialize_meta_info_QSGMaterialShader();
void initialize_meta_info_QSGMaterialShader_GraphicsPipelineState();
void initialize_meta_info_QSGMaterialShader_RenderState();
void initialize_meta_info_QSGMaterialType();
void initialize_meta_info_QSGNinePatchNode();
void initialize_meta_info_QSGNode();
void initialize_meta_info_QSGNodeVisitor();
void initialize_meta_info_QSGOpacityNode();
void initialize_meta_info_QSGOpaqueTextureMaterial();
void initialize_meta_info_QSGRectangleNode();
void initialize_meta_info_QSGRenderNode();
void initialize_meta_info_QSGRenderNode_RenderState();
void initialize_meta_info_QSGRendererInterface();
void initialize_meta_info_QSGRootNode();
void initialize_meta_info_QSGSimpleRectNode();
void initialize_meta_info_QSGSimpleTextureNode();
void initialize_meta_info_QSGTexture();
void initialize_meta_info_QSGTextureMaterial();
void initialize_meta_info_QSGTextureProvider();
void initialize_meta_info_QSGTransformNode();
void initialize_meta_info_QSGVertexColorMaterial();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.quick")

    initialize_meta_info_registerParserStatusCaster();
    initialize_meta_info_QNativeInterface_QSGD3D11Texture();
    initialize_meta_info_QNativeInterface_QSGD3D12Texture();
    initialize_meta_info_QNativeInterface_QSGMetalTexture();
    initialize_meta_info_QNativeInterface_QSGOpenGLTexture();
    initialize_meta_info_QNativeInterface_QSGVulkanTexture();
    initialize_meta_info_QQuickAsyncImageProvider();
    initialize_meta_info_QQuickCloseEvent();
    initialize_meta_info_QQuickFramebufferObject();
    initialize_meta_info_QQuickFramebufferObject_Renderer();
    initialize_meta_info_QQuickGraphicsConfiguration();
    initialize_meta_info_QQuickGraphicsDevice();
    initialize_meta_info_QQuickImageProvider();
    initialize_meta_info_QQuickImageResponse();
    initialize_meta_info_QQuickItem();
    initialize_meta_info_QQuickItem_UpdatePaintNodeData();
    initialize_meta_info_QQuickItemGrabResult();
    initialize_meta_info_QQuickOpenGLUtils();
    initialize_meta_info_QQuickPaintedItem();
    initialize_meta_info_QQuickRenderControl();
    initialize_meta_info_QQuickRenderTarget();
    initialize_meta_info_QQuickTextDocument();
    initialize_meta_info_QQuickTextureFactory();
    initialize_meta_info_QQuickTransform();
    initialize_meta_info_QQuickView();
    initialize_meta_info_QQuickWindow();
    initialize_meta_info_QQuickWindow_GraphicsStateInfo();
    initialize_meta_info_QSGBasicGeometryNode();
    initialize_meta_info_QSGClipNode();
    initialize_meta_info_QSGDynamicTexture();
    initialize_meta_info_QSGFlatColorMaterial();
    initialize_meta_info_QSGGeometry();
    initialize_meta_info_QSGGeometry_Attribute();
    initialize_meta_info_QSGGeometry_AttributeSet();
    initialize_meta_info_QSGGeometry_ColoredPoint2D();
    initialize_meta_info_QSGGeometry_Point2D();
    initialize_meta_info_QSGGeometry_TexturedPoint2D();
    initialize_meta_info_QSGGeometryNode();
    initialize_meta_info_QSGImageNode();
    initialize_meta_info_QSGMaterial();
    initialize_meta_info_QSGMaterialShader();
    initialize_meta_info_QSGMaterialShader_GraphicsPipelineState();
    initialize_meta_info_QSGMaterialShader_RenderState();
    initialize_meta_info_QSGMaterialType();
    initialize_meta_info_QSGNinePatchNode();
    initialize_meta_info_QSGNode();
    initialize_meta_info_QSGNodeVisitor();
    initialize_meta_info_QSGOpacityNode();
    initialize_meta_info_QSGOpaqueTextureMaterial();
    initialize_meta_info_QSGRectangleNode();
    initialize_meta_info_QSGRenderNode();
    initialize_meta_info_QSGRenderNode_RenderState();
    initialize_meta_info_QSGRendererInterface();
    initialize_meta_info_QSGRootNode();
    initialize_meta_info_QSGSimpleRectNode();
    initialize_meta_info_QSGSimpleTextureNode();
    initialize_meta_info_QSGTexture();
    initialize_meta_info_QSGTextureMaterial();
    initialize_meta_info_QSGTextureProvider();
    initialize_meta_info_QSGTransformNode();
    initialize_meta_info_QSGVertexColorMaterial();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_internal_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}
